
package com.bweb.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alipay.api.domain.ForbbidenTime;
import com.alipay.api.domain.OfferObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.pay.util.sdk.WXPayConstants;
import com.hai.common.utils.*;
import com.hai.config.*;
import com.hai.entity.*;
import com.hai.model.OrderRefundModel;
import com.hai.model.ResponseData;
import com.hai.order.service.OrderRefundService;
import com.hai.order.service.OrderService;
import com.hai.order.type.OrderRefundOpUserType;
import com.hai.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @Auther: 胡锐
 * @Description:
 * @Date: 2021/3/26 23:08
 */
@Controller
@RequestMapping(value = "/test")
@Api(value = "订单接口")
public class HighTestController {

    private static Logger log = LoggerFactory.getLogger(HighTestController.class);


    @Resource
    private OutRechargeOrderService outRechargeOrderService;

    @Resource
    private OrderService orderService;

    @Resource
    private HighOrderService highOrderService;


    @RequestMapping(value="/resolveResponse",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "解析")
    public ResponseData resolveResponse(
            @RequestParam(name = "data", required = false) String data
    ) {
        try {
            JSONObject cardInfoObject = HuiLianTongUnionCardConfig.resolveResponse(data);
            return ResponseMsgUtil.success(cardInfoObject);

        } catch (Exception e) {
            log.error("getUserByTelephone",e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value = "/getHuiLianTongCardConsume", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询汇联通工会卡消费记录")
    public ResponseData getHuiLianTongCardConsume(@RequestParam(name = "businessType", required = true) String businessType,
                                                  @RequestParam(name = "cardNo", required = true) String cardNo,
                                                  @RequestParam(name = "sdate", required = true) Long sdate,
                                                  @RequestParam(name = "edate", required = true) Long edate,
                                                  @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                                  @RequestParam(name = "pageSize", required = true) Integer pageSize,
                                                  HttpServletRequest request) {
        try {


            JSONObject consumptionRecord = HuiLianTongUnionCardConfig.queryConsumptionRecordByBusiness(businessType, cardNo, sdate, edate, pageNum, pageSize);
            if (StringUtils.isBlank(consumptionRecord.getString("data"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQUEST_ERROR, "");
            }

            JSONArray array = HuiLianTongUnionCardConfig.resolveResponse(consumptionRecord.getString("data")).getJSONArray("records");

            return ResponseMsgUtil.success(array);

        } catch (Exception e) {
            log.error("HighUserCardController --> getHuiLianTongCardConsume() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/insertV2", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "支付")
    public ResponseData insertV2() {
        try {

            Map<String , Object> map = new HashMap<>();
            map.put("timetable" , new Date().getTime());
            map.put("apiKey" , "9A838BEBC60712775E119366DB804C43");
            map.put("orderNo" , "20220329182036435619");
            map.put("count" , "1");
            map.put("couTypeCode" , "test");
            map.put("phone" , "15206071196");
            map.put("merchId" , "20220670800");
            map.put("sign" , WxUtils.generateSignApi(map, MapUtils.getString(map, "apiKey"), WXPayConstants.SignType.MD5));

            return ResponseMsgUtil.success(HttpsUtils.doPost("https://hsgcs.dctpay.com/v1/gzSinopec/couJointDist" , map));
        } catch (Exception e) {
            log.error("HighOrderController --> getBackendToken() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value = "/phoneBillOrderError", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "话费订单错误")
    public ResponseData phoneBillOrderError() {

        List<HighOrder> highOrders = orderService.phoneErrorOrder();

        JSONObject object;

        for (HighOrder order: highOrders) {
            object = new JSONObject();

            OutRechargeOrder outRechargeOrder = outRechargeOrderService.findByOrderNo(order.getOrderNo());
            OutRechargeChildOrder childOrder = outRechargeOrder.getOutRechargeChildOrders().get(0);
            try {
                if (outRechargeOrder.getPayStatus() == 102 && outRechargeOrder.getRechargeStatus() != 202) {

                    if (outRechargeOrder.getOutRechargeChildOrders().size() == 0) {

                        OutRechargeChildOrder outRechargeChildOrder = new OutRechargeChildOrder();

                        outRechargeChildOrder.setOrderNo("CZ" + DateUtil.date2String(new Date(), "yyyyMMddHHmmss") + IDGenerator.nextId(5));
                        outRechargeChildOrder.setParentOrderId(outRechargeOrder.getId());
                        outRechargeChildOrder.setUpdateTime(new Date());
                        outRechargeChildOrder.setCreateTime(new Date());

                        outRechargeOrderService.refundOrder(outRechargeOrder.getId() , outRechargeChildOrder);
                    } else {
                        if (childOrder.getStatus() != 101) {
                            // 龙阅
                            if (childOrder.getRechargePlatform() == 2) {

                                object.put("out_trade_nums" , childOrder.getOrderNo());

                                JSONObject jsonObject = RechargeConfig.checkOrderByLy(object);

                                JSONArray objectJSONArray = jsonObject.getJSONArray("data");
                                JSONObject objectData = new JSONObject();
                                for (Object objects : objectJSONArray) {
                                    objectData =  (JSONObject) objects;
                                }
                                if (objectData.size() == 0) {
                                    outRechargeOrderService.refundOrder(outRechargeOrder.getId() , childOrder);
                                } else {
                                    // -1取消，0充值中 ，1充值成功，2充值失败，3部分成功
                                    // -1取消，0充值中 ，1充值成功，2充值失败，3部分成功
                                    if (objectData.getInteger("state") == 2 || objectData.getInteger("state") == -1) {
                                        outRechargeOrderService.refundOrder(outRechargeOrder.getId() , childOrder);
                                    } else if (objectData.getInteger("state") == 1) {
                                        outRechargeOrderService.completeOrder(outRechargeOrder , childOrder);
                                    }
                                }

                            }
                            // 嗨购
                            if (childOrder.getRechargePlatform() == 4) {
                                object.put("orderid" , childOrder.getOrderNo());

                                JSONObject jsonObject = RechargeConfig.checkOrderByHg(object);
                                if (jsonObject.getJSONArray("data") == null) {
                                    outRechargeOrderService.refundOrder(outRechargeOrder.getId() , childOrder);
                                } else {
                                    JSONArray objectJSONArray = jsonObject.getJSONArray("data");
                                    JSONObject objectData;
                                    for (Object objects : objectJSONArray) {
                                        objectData =  (JSONObject) objects;
                                        // 充值中1成功2失败3已取消4部分充值5缓存订单
                                        if (objectData.getInteger("status") == 2 || objectData.getInteger("status") == 3) {
                                            outRechargeOrderService.refundOrder(outRechargeOrder.getId() , childOrder);
                                        } else if (objectData.getInteger("status") == 1) {
                                            outRechargeOrderService.completeOrder(outRechargeOrder , childOrder);
                                        }
                                    }
                                }
                            }
                        }
                    }


                }
            } catch (Exception e) {
                log.error("HighUserCardController --> oilCardRefund() error!", e);
            }
        }

            return ResponseMsgUtil.success("null");


    }



    @RequestMapping(value = "/checkOrderByLy", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "龙阅话费查询")
    public ResponseData checkOrderByLy(@RequestParam(name = "orderNo", required = true) String orderNo) {
        try {

            JSONObject object = new JSONObject();

            OutRechargeOrder outRechargeOrder = outRechargeOrderService.findByOrderNo(orderNo);
            OutRechargeChildOrder outRechargeChildOrder = outRechargeOrder.getOutRechargeChildOrders().get(0);
            object.put("out_trade_nums" , outRechargeChildOrder.getOrderNo());

            JSONObject jsonObject = RechargeConfig.checkOrderByLy(object);

            JSONArray objectJSONArray = jsonObject.getJSONArray("data");

            JSONObject objectData = new JSONObject();
            for (Object objects : objectJSONArray) {
                objectData =  (JSONObject) objects;
            }
            if (objectData.size() == 0) {
                outRechargeOrderService.refundOrder(outRechargeOrder.getId() , outRechargeChildOrder);
            } else {
                if (objectData.getInteger("state") == 2 || objectData.getInteger("state") == -1) {
                    outRechargeOrderService.refundOrder(outRechargeOrder.getId() , outRechargeChildOrder);
                } else if (objectData.getInteger("state") == 1) {
                    outRechargeOrderService.completeOrder(outRechargeOrder , outRechargeChildOrder);
                }
            }

            return ResponseMsgUtil.success(objectJSONArray);
        } catch (Exception e) {
            log.error("HighOrderController --> getBackendToken() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/checkOrderByLyDetail", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "龙阅话费查询")
    public ResponseData checkOrderByLyDetail(@RequestParam(name = "orderNo", required = true) String orderNo) {
        try {

            JSONObject object = new JSONObject();

            OutRechargeOrder outRechargeOrder = outRechargeOrderService.findByOrderNo(orderNo);
            OutRechargeChildOrder outRechargeChildOrder = outRechargeOrder.getOutRechargeChildOrders().get(0);
            object.put("out_trade_nums" , outRechargeChildOrder.getOrderNo());

            JSONObject jsonObject = RechargeConfig.checkOrderByLy(object);

            JSONArray objectJSONArray = jsonObject.getJSONArray("data");

            JSONObject objectData = new JSONObject();
            for (Object objects : objectJSONArray) {
                objectData =  (JSONObject) objects;
            }
            if (objectData.size() == 0) {
                return ResponseMsgUtil.success("无订单退款");
            } else {
                if (objectData.getInteger("state") == 2 || objectData.getInteger("state") == -1) {
                    return ResponseMsgUtil.success("退款");
                } else if (objectData.getInteger("state") == 1) {
                    return ResponseMsgUtil.success("完成订单");
                }
            }

            return ResponseMsgUtil.success(objectJSONArray);
        } catch (Exception e) {
            log.error("HighOrderController --> getBackendToken() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/phoneBillOrderMigration", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "话费订单迁移")
    public ResponseData phoneBillOrderMigration() {
        try {

            Map<String , Object> map = new HashMap<>();
            map.put("productType" , 9);

            List<HighOrder> list  = highOrderService.getOrderList(map);

            for (HighOrder order : list) {
                OutRechargeOrder outRechargeOrder = outRechargeOrderService.findByOrderNo(order.getOrderNo());

                order.setTitle(outRechargeOrder.getRechargeContent() + order.getTitle());

                highOrderService.updateOrder(order);
            }

            return ResponseMsgUtil.success(list);

        } catch (Exception e) {
            log.error("HighUserCardController --> oilCardRefund() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }
}


